@@ -20,7 +20,7 @@ class Eos:
     def generate_key_pair(cls):
         response = muterun_js(cls.current_dir + '/js/GenerateKeys.js')
         if response.exitcode == 0:
-            data = load_data(response.stdout)
+            data = self.load_data(response.stdout)
             return data
         else:
             raise GenerateKeysException(response.stderr)
@@ -43,7 +43,7 @@ class Eos:
         )
         response = muterun_js(self.current_dir + '/js/CreateAccount.js', arguments=arguments)
         if response.exitcode == 0:
-            data = load_data(response.stdout)
+            data = self.load_data(response.stdout)
             return data
         else:
             raise CreateAccountException(response.stderr)
@@ -63,7 +63,7 @@ class Eos:
         )
         response = muterun_js(self.current_dir + '/js/PushContractTransaction.js', arguments=arguments)
         if response.exitcode == 0:
-            data = load_data(response.stdout)
+            data = self.load_data(response.stdout)
             return data
         else:
             raise PushContractTransactionException(response.stderr)
@@ -83,7 +83,7 @@ class Eos:
         )
         response = muterun_js(self.current_dir + '/js/GetTable.js', arguments=arguments)
         if response.exitcode == 0:
-            data = load_data(response.stdout)
+            data = self.load_data(response.stdout)
             return data
         else:
             raise GetTableException(response.stderr)
@@ -101,14 +101,14 @@ class Eos:
         )
         response = muterun_js(self.current_dir + '/js/GetCurrencyBalance.js', arguments=arguments)
         if response.exitcode == 0:
-            data = load_data(response.stdout)
+            data = self.load_data(response.stdout)
             return data
         else:
             raise GetBalanceException(response.stderr)
 
 
-def load_data(stdout):
-    true_string = stdout.decode('utf8')
-    if self.debug_mode:
-        print(true_string)
-    return json.loads(true_string)
+    def load_data(self, stdout):
+        true_string = stdout.decode('utf8')
+        if self.debug_mode:
+            print(true_string)
+        return json.loads(true_string)
